aboutsummaryrefslogtreecommitdiff
path: root/src/Java/miscutil/gregtech/api/interfaces
diff options
context:
space:
mode:
Diffstat (limited to 'src/Java/miscutil/gregtech/api/interfaces')
-rw-r--r--src/Java/miscutil/gregtech/api/interfaces/internal/IGregtech_RecipeAdder.java14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/Java/miscutil/gregtech/api/interfaces/internal/IGregtech_RecipeAdder.java b/src/Java/miscutil/gregtech/api/interfaces/internal/IGregtech_RecipeAdder.java
index 049611149e..8aa77d75ba 100644
--- a/src/Java/miscutil/gregtech/api/interfaces/internal/IGregtech_RecipeAdder.java
+++ b/src/Java/miscutil/gregtech/api/interfaces/internal/IGregtech_RecipeAdder.java
@@ -5,18 +5,18 @@ import net.minecraftforge.fluids.FluidStack;
public interface IGregtech_RecipeAdder {
/**
- * Adds a FusionreactorRecipe
+ * Adds a Coke Oven Recipe
*
- * @param aOptimize = EU needed for heating up (must be >= 0)
- * @param aInput1 = first Input (can be null, and respects StackSize)
+ * @param aInput1 = first Input (not null, and respects StackSize)
+ * @param aInputb = second Input (can be null, and respects StackSize)
* @param aOutput1 = Output of the Creosote (not null, and respects StackSize)
* @param bInput1 = first solid Input (not null, and respects StackSize)
* @param bOutput1 = Output of the Coal/coke (can be null, and respects StackSize)
* @param aDuration = Duration (must be >= 0)
* @param aEUt = EU needed for heating up (must be >= 0)
- * @param aSpecialValue = EU needed for heating up (must be >= 0)
* @return true if the Recipe got added, otherwise false.
*/
- public boolean addCokeOvenRecipe(boolean aOptimize, ItemStack[] aInputs, ItemStack[] aOutputs, Object aSpecial, FluidStack[] aFluidInputs, FluidStack[] aFluidOutputs, int aDuration, int aEUt, int aSpecialValue);
+ //public boolean addCokeOvenRecipe(boolean aOptimize, ItemStack[] aInputs, ItemStack[] aOutputs, Object aSpecial, FluidStack[] aFluidInputs, FluidStack[] aFluidOutputs, int aDuration, int aEUt, int aSpecialValue);
+ public boolean addCokeOvenRecipe(ItemStack aInput1, ItemStack aInput2, FluidStack aFluidInput, FluidStack aFluidOutput, ItemStack aOutput, int aDuration, int aEUt);
}
@@ -5,18 +5,18 @@ import net.minecraftforge.fluids.FluidStack;
* @param aOutput1 = Output of the Creosote (not null, and respects StackSize)
- * @param bInput1 = first solid Input (not null, and respects StackSize)
- * @param bOutput1 = Output of the Coal/coke (can be null, and respects StackSize)
+ * @param aFluidInput = fluid Input (can be null, and respects StackSize)
+ * @param aOutput = Output of the Coal/coke (can be null, and respects StackSize)
* @param aDuration = Duration (must be >= 0)
* @param aEUt = EU needed for heating up (must be >= 0)